<?php
//
// Example of usage for Services_AmazonECS4
//
// This example uses the following functions:
// - CartAdd
// - CartClear
// - CartCreate
// - CartGet
// - CartModify
//
// * VERY IMPORTANT *
// YOU NEED TO CHANGE THE SUBSCRIPTION TO SOMETHING OTHER THEN [your Subscription ID here]
// YOU ALSO SHOULD CHANGE THE ASSOSCIATE ID TO YOUR OWN
// * VERY IMPORTANT *

require_once 'PEAR.php';
require_once 'Services/AmazonECS4.php';

function existsCart()
{
    return isset($_COOKIE['CartId']) ? true : false;
}

$amazon = new Services_AmazonECS4('[your Subscription ID here]', '[your Associate ID]');

switch ($_GET['action']) {
case 'add':
    $item = array('ASIN' => $_GET['ASIN'],
                  'Quantity' => $_GET['Quantity']);
    if (!existsCart()) {
        $result = $amazon->CartCreate($item);
        if (PEAR::isError($result)) {
            die($result->message);
        }
        setcookie('CartId', $result['CartId'], time() + 60*60*24);
        setcookie('HMAC', $result['HMAC'], time() + 60*60*24);
    } else {
        $result = $amazon->CartAdd($_COOKIE['CartId'], $_COOKIE['HMAC'], $item);
        if (PEAR::isError($result)) {
            die($result->message);
        }
    }
    break;

case 'modify':
    if (!existsCart()) {
        die('error');
    }
    $item = array('CartItemId' => $_GET['CartItemId']);
    if (isset($_GET['SaveForLater'])) {
        $item += array('Action' => 'SaveForLater');
    } else if (isset($_GET['MoveToCart'])) {
        $item += array('Action' => 'MoveToCart');
    } else {
        $item += array('Quantity' => $_GET['Quantity']);
    }
    $result = $amazon->CartModify($_COOKIE['CartId'], $_COOKIE['HMAC'], $item);
    if (PEAR::isError($result)) {
        die($result->message);
    }
    
    break;

case 'clear':
    if (!existsCart()) {
        die('error');
    }
    $result = $amazon->CartClear($_COOKIE['CartId'], $_COOKIE['HMAC']);
    break;

default:
    if (existsCart()) {
        $result = $amazon->CartGet($_COOKIE['CartId'], $_COOKIE['HMAC']);
        if (PEAR::isError($result)) {
            setcookie('CartId', null, 0);
            setcookie('HMAC', null, 0);
            die($result->message);
        }
    }
    break;
}

echo <<< EOT
<html>
<head>
    <meta http-equiv="Content-type" content="text/html; charset=UTF-8" />
    <title>Services_AmazonECS4 example</title>
</head>
<body>
<h1>Amazon ECS4 example - Cart Operations</h1>
<p>

</p>
EOT;

echo <<< EOT
<form action="{$_SERVER['PHP_SELF']}" method="get">
<table border="0">
<tr>
    <td>ASIN <input type="text" name="ASIN" size="20" /></td>
    <td>Quantity <input type="text" name="Quantity" size="3" value="1" /></td>
    <td><input type="submit" value="Add to cart" /></td>
</tr>
</table>
<input type="hidden" name="action" value="add" />
</form>
EOT;

// CartItems
echo <<< EOT
CartItems :<br />
<table border="1">
<tr><th>ASIN</th><th>Title</th><th>Price</th><th>Qty</th><th>Save</th><th></th></tr>
EOT;
$items = array();
if (isset($result)) {
    if (isset($result['CartItems']['CartItem']['CartItemId'])) {
        $items['0'] = $result['CartItems']['CartItem'];
    } else if (isset($result['CartItems']['CartItem'])) {
        $items += $result['CartItems']['CartItem'];
    }
}
foreach ($items as $v) {
echo <<< EOT
    <tr>
        <form action="{$_SERVER['PHP_SELF']}" method="get">
        <td>{$v['ASIN']}</td>
        <td>{$v['Title']}</td>
        <td>{$v['Price']['FormattedPrice']}</td>
        <td>
            <input type="text" size="3" name="Quantity" value="{$v['Quantity']}" />
            <input type="hidden" name="CartItemId" value="{$v['CartItemId']}" />
        </td>
        <td>
            <input type="checkbox" name="SaveForLater" value="save" />
        </td>
        <td>
            <input type="submit" value="Update" />
        </td>
        <input type="hidden" name="action" value="modify" />
        </form>
    </tr>
EOT;
}
echo <<< EOT
</table><br />
EOT;

// Saved Items
echo <<< EOT
Saved Items to buy later :<br />
<table border="1">
<tr><th>ASIN</th><th>Title</th><th>Price</th><th>Qty</th><th>Move</th><th></th></tr>
EOT;
$items = array();
if (isset($result)) {
    if (isset($result['SavedForLaterItems']['SavedForLaterItem']['CartItemId'])) {
        $items['0'] = $result['SavedForLaterItems']['SavedForLaterItem'];
    } else if (isset($result['SavedForLaterItems']['SavedForLaterItem'])) {
        $items += $result['SavedForLaterItems']['SavedForLaterItem'];
    }
}
foreach ($items as $v) {
echo <<< EOT
    <tr>
        <form action="{$_SERVER['PHP_SELF']}" method="get">
        <td>{$v['ASIN']}</td>
        <td>{$v['Title']}</td>
        <td>{$v['Price']['FormattedPrice']}</td>
        <td>
            <input type="text" size="3" name="Quantity" value="{$v['Quantity']}" />
            <input type="hidden" name="CartItemId" value="{$v['CartItemId']}" />
        </td>
        <td>
            <input type="checkbox" name="MoveToCart" value="move" />
        </td>
        <td>
            <input type="submit" value="Update" />
        </td>
        <input type="hidden" name="action" value="modify" />
        </form>
    </tr>
EOT;
}
echo <<< EOT
</table><br />
EOT;

// Clear
if (isset($result['CartItems']) || isset($result['SavedForLaterItems'])) {
echo <<< EOT
<p><a href="{$_SERVER['PHP_SELF']}?action=clear">Clear</a></p>
EOT;
}
    
// Purchase
if (isset($result['CartItems']) || isset($result['SavedForLaterItems'])) {
echo <<< EOT
<p><a href="{$result['PurchaseURL']}">Purchase</a></p>
EOT;
}

// Processing Time
echo '<p>Processing Time : ' . $amazon->getProcessingTime() . 'sec</p>';

// Result
echo '<p>Result :';
var_dump($result);
echo '</p>';

echo <<< EOT
</body>
</html>
EOT;

?>
